@@ -41,8 +41,22 @@ def today() -> str:
     return f'{yyyy}-{mm}-{dd}'
 
 def to_datetime(datetime_str: Optional[str]) -> Optional[datetime]:
-    if datetime_str is None: return None
-    return datetime.strptime(datetime_str, '%Y-%m-%dT%H:%M:%S.%f') 
+    if datetime_str is None:
+        return None
+
+    if 'T' in datetime_str:
+        if '.' in datetime_str:
+            return datetime.strptime(datetime_str, '%Y-%m-%dT%H:%M:%S.%f')
+        return datetime.strptime(datetime_str, '%Y-%m-%dT%H:%M:%S')
+
+    if ' ' in datetime_str:
+        if '.' in datetime_str:
+            return datetime.strptime(datetime_str, '%Y-%m-%d %H:%M:%S.%f')
+        return datetime.strptime(datetime_str, '%Y-%m-%d %H:%M:%S')
+
+    if '.' in datetime_str:
+        return datetime.strptime(datetime_str, '%Y-%m-%d%H:%M:%S.%f')
+    return datetime.strptime(datetime_str, '%Y-%m-%d%H:%M:%S')
 
 def format_cents(price_in_cents: int) -> str:
     whole, fractional = map(str, divmod(price_in_cents, 100))
