@@ -199,11 +199,13 @@ class Template:
         self,
         id: int,
         name: str,
+        message: str,
         thumbnail: str,
         gifts: List[Gift],
     ) -> None:
         self._id = id
         self._name = name
+        self._message = None if message == 'False' else message
         self._thumbnail = thumbnail
         self._gifts = gifts
         self._gifts_total = sum(gift.total_cost for gift in gifts)
@@ -220,6 +222,11 @@ class Template:
         """Template's name."""
         return self._name
 
+    @property
+    def message(self) -> str:
+        """Template's message on default panel."""
+        return self._message
+
     @property
     def thumbnail(self) -> str:
         """Template's image thumbnail."""
@@ -240,6 +247,7 @@ class Template:
         return cls(
             id=json['id'],
             name=json['name'],
+            message=json['has_message_on_default_panel'],
             thumbnail=json['thumbnail'],
             gifts=[Gift._from_json(gift_json) for gift_json in json['gifts']],
         )
@@ -353,6 +361,16 @@ class Card:
         """The date the card is sent. The format should be: ``"YYYY-MM-DD"``."""
         return self._send_date
 
+    @property
+    def edit_link(self) -> str:
+        """This is the link to edit the card inside of AMcards.com."""
+        return f'https://amcards.com/cards/edit/{self._id}/'
+
+    @property
+    def cancel_link(self) -> str:
+        """This is the link to cancel the card inside of AMcards.com."""
+        return f'https://amcards.com/cards/cancel/{self._id}/'
+
     @property
     def date_created(self) -> datetime:
         """Date and time card was created."""
